@@ -24,8 +24,8 @@ from pyramid.config import Configurator
 from pyramid.view import view_config, view_defaults
 from pyramid.response import Response
 from github import Github
-
-
+import datetime
+from apscheduler.schedulers.background import BlockingScheduler
 
 
 ENDPOINT = "webhook"
@@ -64,24 +64,17 @@ class PayloadView():
         return Response("success")
 
 
-# create webhook on a particular repo
-# '''create webhook on a particular repo '''
-         
-            # param : 
-            # token is the argument which is a aceess token for getting access to the
-            # github repository.
-            # username is github account name
-            # hostname is the server ip/address
-            # reponame is the repositery name
-            
-            # Variables Used:
-            # access_token : Stores the github access token 
-            # REPO_NAME : stores the reposirory 
-            # OWNER : stores the account name
-            # EVENTS : Events trigered
-            # HOST : server ip to run server
 
-            
+
+# def pull():
+#     path=pathlib.Path().resolve()
+#     path=path+repo_name
+#     print(folder)
+#     repo = git.Repo(folder)
+#     origin = repo.remote(name='origin')
+#     origin.pull()
+
+         
 @click.command()
 def init():
     '''
@@ -100,10 +93,11 @@ def init():
 
         response = requests.get("https://app.buildpan.com/api/v1/projects/detail/"+project_id)
         data = response.json()
-    
-        # print(response.status_code)
+       
+
+        print(response.status_code)
         # print(response.json())
-            
+        print("flag1")
         name = data["project"]["repo"]["full_name"].split('/')
         token = data["project"]["githubtoken"]
         username = name[0]
@@ -125,26 +119,27 @@ def init():
         
         # Serializing json 
         json_object = json.dumps(dictionary, indent = 4)
-        
+        print("fla21")
         # Writing to sample.json
-        with open('sample.json') as outfile:
+        with open(project_id+'.json',"w") as outfile:
             outfile.write(json_object)
         
     
-
-        with open('sample.json') as f:
+        print("flag3")
+        with open(project_id+'.json') as f:
          data = json.load(f)
          username = data["username"]
          token=data["token"]
          repo_name=data["repo_name"]
-
+          
+        print("flag4")
 
         access_token =token #"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"
         OWNER = username #"AkashAi7" # github account name
         REPO_NAME =repo_name#"Web-Scrapping-Using-Selenium-Python-"# github repository name
         EVENTS = ["*"]      # Events on github
         HOST = "35.225.89.124"  # ngrok tunnel
-    
+           
         config = {
             "url": "http://{host}/{endpoint}".format(host=HOST, endpoint=ENDPOINT),
             "content_type": "json"
@@ -160,9 +155,28 @@ def init():
         # creating a webhook on a particular repository
         try:
           repo.create_hook("web", config, EVENTS, active=True)
+         
+        #   pull
+          repo = git.Repo(path)
+          origin = repo.remote(name='origin')
+          res=origin.pull()
+          response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name})
+           #success , project id , repo name , current date and time , email id
+          print("status code is ",response2.status_code)
+
         except:
             print("webhook already exists on this repository ")
-        
+
+                 #   pull
+            repo = git.Repo(path)
+            origin = repo.remote(name='origin')
+            res=origin.pull()
+            time = datetime.datetime.now()
+            response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':time,'user_name':username})
+           #success , project id , repo name , current date and time , email id'
+            print("status code is ",response2.status_code)
+
+          
     except:
         print("config file not found")
 
